/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
import { Injectable, EventEmitter } from '@angular/core';
import { EsriModuleProvider } from './esri-module-provider';
export class EsriMapService {
    /**
     * @param {?} moduleProvider
     */
    constructor(moduleProvider) {
        this.moduleProvider = moduleProvider;
        this.isLoaded = new EventEmitter();
    }
    /**
     * @param {?} mapViewProperties
     * @param {?} mapEl
     * @param {?} map
     * @return {?}
     */
    prepareViewProps(mapViewProperties, mapEl, map) {
        const /** @type {?} */ newViewProps = this.extend({}, mapViewProperties);
        if (!newViewProps.container) {
            newViewProps.container = mapEl.nativeElement.id;
        }
        if (!newViewProps.map) {
            newViewProps.map = map;
        }
        return newViewProps;
    }
    /**
     * @param {?} mapProperties
     * @param {?} viewProperties
     * @param {?} mapEl
     * @param {?=} viewType
     * @return {?}
     */
    loadMap(mapProperties, viewProperties, mapEl, viewType = 'MapView') {
        return this.moduleProvider
            .require(['esri/Map', 'esri/views/' + viewType])
            .then(([Map, View]) => {
            // create map
            const /** @type {?} */ map = new Map(mapProperties);
            // prepare properties that should be set locally
            // create a new object so as to not modify the provided object
            const /** @type {?} */ newViewProps = this.prepareViewProps(viewProperties, mapEl, map);
            // create the MapView
            const /** @type {?} */ view = new View(newViewProps);
            this.map = map;
            this.view = view;
            this.isLoaded.emit();
            return {
                map: map,
                view: view
            };
        });
    }
    /**
     * @param {?} webMapProperties
     * @param {?} viewProperties
     * @param {?} mapEl
     * @param {?=} viewType
     * @return {?}
     */
    loadWebMap(webMapProperties, viewProperties, mapEl, viewType = 'MapView') {
        return this.moduleProvider
            .require(['esri/WebMap', 'esri/views/' + viewType])
            .then(([WebMap, View]) => {
            // create map
            const /** @type {?} */ map = new WebMap(webMapProperties);
            // prepare properties that should be set locally
            // create a new object so as to not modify the provided object
            const /** @type {?} */ newViewProps = this.prepareViewProps(viewProperties, mapEl, map);
            // create the MapView
            const /** @type {?} */ view = new View(newViewProps);
            this.map = map;
            this.view = view;
            this.isLoaded.emit();
            return {
                map: map,
                view: view
            };
        });
    }
    /**
     * @param {?} element
     * @param {?} position
     * @return {?}
     */
    addWidget(element, position) {
        this.view.ui.add(element, position);
    }
    /**
     * @param {?} obj
     * @param {?} src
     * @return {?}
     */
    extend(obj, src) {
        Object.keys(src).forEach(key => {
            obj[key] = src[key];
        });
        return obj;
    }
}
EsriMapService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
EsriMapService.ctorParameters = () => [
    { type: EsriModuleProvider, },
];
function EsriMapService_tsickle_Closure_declarations() {
    /** @type {!Array<{type: !Function, args: (undefined|!Array<?>)}>} */
    EsriMapService.decorators;
    /**
     * @nocollapse
     * @type {function(): !Array<(null|{type: ?, decorators: (undefined|!Array<{type: !Function, args: (undefined|!Array<?>)}>)})>}
     */
    EsriMapService.ctorParameters;
    /** @type {?} */
    EsriMapService.prototype.isLoaded;
    /** @type {?} */
    EsriMapService.prototype.map;
    /** @type {?} */
    EsriMapService.prototype.view;
    /** @type {?} */
    EsriMapService.prototype.moduleProvider;
}
//# sourceMappingURL=esri-map.service.js.map
