/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
import { Component, Input, Output, ElementRef, ViewChild, EventEmitter } from '@angular/core';
import { EsriMapService } from './../core/esri-map.service';
import { environment } from './../../environments/environment';
export class MapComponent {
    /**
     * @param {?} mapService
     */
    constructor(mapService) {
        this.mapService = mapService;
        this.mapViewProperties = {};
        this.viewType = 'MapView';
        this.mapInit = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.map) {
            // map is already initialized
            return;
        }
        this.loadMap();
    }
    /**
     * @return {?}
     */
    loadMap() {
        let /** @type {?} */ mapPromise;
        // determine if loading a WebMap or creating a custom map
        if (this.mapProperties) {
            mapPromise = this.mapService.loadMap(this.mapProperties, this.mapViewProperties, this.mapEl, this.viewType);
        }
        else if (this.webMapProperties) {
            mapPromise = this.mapService.loadWebMap(this.webMapProperties, this.mapViewProperties, this.mapEl, this.viewType);
        }
        else {
            console.error('Proper map properties were not provided');
            return;
        }
        mapPromise.then((mapInfo) => {
            this.map = mapInfo.map;
            this.mapView = mapInfo.view;
            // emit event informing application that the map has been loaded
            this.mapInit.emit({
                map: this.map,
                mapView: this.mapView
            });
            this.mapInit.complete();
        });
    }
}
MapComponent.decorators = [
    { type: Component, args: [{
                selector: 'esri-map',
                template: `<div class="map" id="esri-map" #map></div>`,
                styles: [`
    /* Required CSS for the ArcGIS API for JavaScript */
    @import '${environment.arcGisCssUrl}';
    .map {
      height: 100%;
      width: 100%;
      margin: 0;
      padding: 0;
    }
  `]
            },] },
];
/** @nocollapse */
MapComponent.ctorParameters = () => [
    { type: EsriMapService, },
];
MapComponent.propDecorators = {
    "mapEl": [{ type: ViewChild, args: ['map',] },],
    "mapProperties": [{ type: Input },],
    "webMapProperties": [{ type: Input },],
    "mapViewProperties": [{ type: Input },],
    "viewType": [{ type: Input },],
    "mapInit": [{ type: Output },],
};
function MapComponent_tsickle_Closure_declarations() {
    /** @type {!Array<{type: !Function, args: (undefined|!Array<?>)}>} */
    MapComponent.decorators;
    /**
     * @nocollapse
     * @type {function(): !Array<(null|{type: ?, decorators: (undefined|!Array<{type: !Function, args: (undefined|!Array<?>)}>)})>}
     */
    MapComponent.ctorParameters;
    /** @type {!Object<string,!Array<{type: !Function, args: (undefined|!Array<?>)}>>} */
    MapComponent.propDecorators;
    /** @type {?} */
    MapComponent.prototype.map;
    /** @type {?} */
    MapComponent.prototype.mapView;
    /** @type {?} */
    MapComponent.prototype.mapEl;
    /** @type {?} */
    MapComponent.prototype.mapProperties;
    /** @type {?} */
    MapComponent.prototype.webMapProperties;
    /** @type {?} */
    MapComponent.prototype.mapViewProperties;
    /** @type {?} */
    MapComponent.prototype.viewType;
    /** @type {?} */
    MapComponent.prototype.mapInit;
    /** @type {?} */
    MapComponent.prototype.mapService;
}
//# sourceMappingURL=map.component.js.map
