/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
import { Component, Input, Output, ViewChild, EventEmitter } from '@angular/core';
import { EsriMapService } from './../core/esri-map.service';
import { environment } from './../../environments/environment';
var MapComponent = /** @class */ (function () {
    /**
     * @param {?} mapService
     */
    function MapComponent(mapService) {
        this.mapService = mapService;
        this.mapViewProperties = {};
        this.viewType = 'MapView';
        this.mapInit = new EventEmitter();
    }
    /**
     * @return {?}
     */
    MapComponent.prototype.ngOnInit = function () {
        if (this.map) {
            // map is already initialized
            return;
        }
        this.loadMap();
    };
    /**
     * @return {?}
     */
    MapComponent.prototype.loadMap = function () {
        var _this = this;
        var /** @type {?} */ mapPromise;
        // determine if loading a WebMap or creating a custom map
        if (this.mapProperties) {
            mapPromise = this.mapService.loadMap(this.mapProperties, this.mapViewProperties, this.mapEl, this.viewType);
        }
        else if (this.webMapProperties) {
            mapPromise = this.mapService.loadWebMap(this.webMapProperties, this.mapViewProperties, this.mapEl, this.viewType);
        }
        else {
            console.error('Proper map properties were not provided');
            return;
        }
        mapPromise.then(function (mapInfo) {
            _this.map = mapInfo.map;
            _this.mapView = mapInfo.view;
            // emit event informing application that the map has been loaded
            _this.mapInit.emit({
                map: _this.map,
                mapView: _this.mapView
            });
            _this.mapInit.complete();
        });
    };
    return MapComponent;
}());
export { MapComponent };
MapComponent.decorators = [
    { type: Component, args: [{
                selector: 'esri-map',
                template: "<div class=\"map\" id=\"esri-map\" #map></div>",
                styles: ["\n    /* Required CSS for the ArcGIS API for JavaScript */\n    @import '" + environment.arcGisCssUrl + "';\n    .map {\n      height: 100%;\n      width: 100%;\n      margin: 0;\n      padding: 0;\n    }\n  "]
            },] },
];
/** @nocollapse */
MapComponent.ctorParameters = function () { return [
    { type: EsriMapService, },
]; };
MapComponent.propDecorators = {
    "mapEl": [{ type: ViewChild, args: ['map',] },],
    "mapProperties": [{ type: Input },],
    "webMapProperties": [{ type: Input },],
    "mapViewProperties": [{ type: Input },],
    "viewType": [{ type: Input },],
    "mapInit": [{ type: Output },],
};
function MapComponent_tsickle_Closure_declarations() {
    /** @type {!Array<{type: !Function, args: (undefined|!Array<?>)}>} */
    MapComponent.decorators;
    /**
     * @nocollapse
     * @type {function(): !Array<(null|{type: ?, decorators: (undefined|!Array<{type: !Function, args: (undefined|!Array<?>)}>)})>}
     */
    MapComponent.ctorParameters;
    /** @type {!Object<string,!Array<{type: !Function, args: (undefined|!Array<?>)}>>} */
    MapComponent.propDecorators;
    /** @type {?} */
    MapComponent.prototype.map;
    /** @type {?} */
    MapComponent.prototype.mapView;
    /** @type {?} */
    MapComponent.prototype.mapEl;
    /** @type {?} */
    MapComponent.prototype.mapProperties;
    /** @type {?} */
    MapComponent.prototype.webMapProperties;
    /** @type {?} */
    MapComponent.prototype.mapViewProperties;
    /** @type {?} */
    MapComponent.prototype.viewType;
    /** @type {?} */
    MapComponent.prototype.mapInit;
    /** @type {?} */
    MapComponent.prototype.mapService;
}
//# sourceMappingURL=map.component.js.map
