import { Injectable, EventEmitter, Component, Input, Output, ElementRef, ViewChild, Directive, NgModule } from '@angular/core';
import { loadModules } from 'esri-loader';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const /** @type {?} */ environment = {
    production: true,
    arcGisScriptUrl: 'https://js.arcgis.com/4.7/',
    arcGisCssUrl: 'http://js.arcgis.com/4.7/esri/css/main.css'
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EsriModuleProvider {
    constructor() { }
    /**
     * @param {?} moduleNames
     * @return {?}
     */
    require(moduleNames) {
        return loadModules(moduleNames, {
            // the specific version of the API that is to be used
            url: environment.arcGisScriptUrl
        });
    }
}
EsriModuleProvider.decorators = [
    { type: Injectable },
];
/** @nocollapse */
EsriModuleProvider.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EsriMapService {
    /**
     * @param {?} moduleProvider
     */
    constructor(moduleProvider) {
        this.moduleProvider = moduleProvider;
        this.isLoaded = new EventEmitter();
    }
    /**
     * @param {?} mapViewProperties
     * @param {?} mapEl
     * @param {?} map
     * @return {?}
     */
    prepareViewProps(mapViewProperties, mapEl, map) {
        const /** @type {?} */ newViewProps = this.extend({}, mapViewProperties);
        if (!newViewProps.container) {
            newViewProps.container = mapEl.nativeElement.id;
        }
        if (!newViewProps.map) {
            newViewProps.map = map;
        }
        return newViewProps;
    }
    /**
     * @param {?} mapProperties
     * @param {?} viewProperties
     * @param {?} mapEl
     * @param {?=} viewType
     * @return {?}
     */
    loadMap(mapProperties, viewProperties, mapEl, viewType = 'MapView') {
        return this.moduleProvider
            .require(['esri/Map', 'esri/views/' + viewType])
            .then(([Map, View]) => {
            // create map
            const /** @type {?} */ map = new Map(mapProperties);
            // prepare properties that should be set locally
            // create a new object so as to not modify the provided object
            const /** @type {?} */ newViewProps = this.prepareViewProps(viewProperties, mapEl, map);
            // create the MapView
            const /** @type {?} */ view = new View(newViewProps);
            this.map = map;
            this.view = view;
            this.isLoaded.emit();
            return {
                map: map,
                view: view
            };
        });
    }
    /**
     * @param {?} webMapProperties
     * @param {?} viewProperties
     * @param {?} mapEl
     * @param {?=} viewType
     * @return {?}
     */
    loadWebMap(webMapProperties, viewProperties, mapEl, viewType = 'MapView') {
        return this.moduleProvider
            .require(['esri/WebMap', 'esri/views/' + viewType])
            .then(([WebMap, View]) => {
            // create map
            const /** @type {?} */ map = new WebMap(webMapProperties);
            // prepare properties that should be set locally
            // create a new object so as to not modify the provided object
            const /** @type {?} */ newViewProps = this.prepareViewProps(viewProperties, mapEl, map);
            // create the MapView
            const /** @type {?} */ view = new View(newViewProps);
            this.map = map;
            this.view = view;
            this.isLoaded.emit();
            return {
                map: map,
                view: view
            };
        });
    }
    /**
     * @param {?} element
     * @param {?} position
     * @return {?}
     */
    addWidget(element, position) {
        this.view.ui.add(element, position);
    }
    /**
     * @param {?} obj
     * @param {?} src
     * @return {?}
     */
    extend(obj, src) {
        Object.keys(src).forEach(key => {
            obj[key] = src[key];
        });
        return obj;
    }
}
EsriMapService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
EsriMapService.ctorParameters = () => [
    { type: EsriModuleProvider, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class MapComponent {
    /**
     * @param {?} mapService
     */
    constructor(mapService) {
        this.mapService = mapService;
        this.mapViewProperties = {};
        this.viewType = 'MapView';
        this.mapInit = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.map) {
            // map is already initialized
            return;
        }
        this.loadMap();
    }
    /**
     * @return {?}
     */
    loadMap() {
        let /** @type {?} */ mapPromise;
        // determine if loading a WebMap or creating a custom map
        if (this.mapProperties) {
            mapPromise = this.mapService.loadMap(this.mapProperties, this.mapViewProperties, this.mapEl, this.viewType);
        }
        else if (this.webMapProperties) {
            mapPromise = this.mapService.loadWebMap(this.webMapProperties, this.mapViewProperties, this.mapEl, this.viewType);
        }
        else {
            console.error('Proper map properties were not provided');
            return;
        }
        mapPromise.then((mapInfo) => {
            this.map = mapInfo.map;
            this.mapView = mapInfo.view;
            // emit event informing application that the map has been loaded
            this.mapInit.emit({
                map: this.map,
                mapView: this.mapView
            });
            this.mapInit.complete();
        });
    }
}
MapComponent.decorators = [
    { type: Component, args: [{
                selector: 'esri-map',
                template: `<div class="map" id="esri-map" #map></div>`,
                styles: [`
    /* Required CSS for the ArcGIS API for JavaScript */
    @import '${environment.arcGisCssUrl}';
    .map {
      height: 100%;
      width: 100%;
      margin: 0;
      padding: 0;
    }
  `]
            },] },
];
/** @nocollapse */
MapComponent.ctorParameters = () => [
    { type: EsriMapService, },
];
MapComponent.propDecorators = {
    "mapEl": [{ type: ViewChild, args: ['map',] },],
    "mapProperties": [{ type: Input },],
    "webMapProperties": [{ type: Input },],
    "mapViewProperties": [{ type: Input },],
    "viewType": [{ type: Input },],
    "mapInit": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class CustomWidgetDirective {
    /**
     * @param {?} el
     * @param {?} mapService
     */
    constructor(el, mapService) {
        this.el = el;
        this.mapService = mapService;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.mapService.isLoaded.subscribe(() => {
            // after map is loaded then add widget
            this.mapService.addWidget(this.el.nativeElement, this.position);
        });
    }
}
CustomWidgetDirective.decorators = [
    { type: Directive, args: [{
                selector: '[esriCustomWidget], [esri-customWidget]'
            },] },
];
/** @nocollapse */
CustomWidgetDirective.ctorParameters = () => [
    { type: ElementRef, },
    { type: EsriMapService, },
];
CustomWidgetDirective.propDecorators = {
    "position": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class LayersToggleComponent {
    /**
     * @param {?} mapService
     */
    constructor(mapService) {
        this.mapService = mapService;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.mapService.isLoaded.subscribe(() => {
            this.map = this.mapService.map;
            this.view = this.mapService.view;
        });
    }
    /**
     * @param {?} $event
     * @param {?} layer
     * @return {?}
     */
    onCheck($event, layer) {
        layer.visible = $event.target.checked;
    }
    /**
     * @param {?} layer
     * @return {?}
     */
    onZoomLayer(layer) {
        if (this.view.type === '2d') {
            (/** @type {?} */ (this.view)).goTo(layer.fullExtent);
        }
        else {
            const /** @type {?} */ sceneView = /** @type {?} */ (this.view);
            sceneView.goTo({
                target: layer.fullExtent,
                heading: sceneView.camera.heading
            });
        }
    }
}
LayersToggleComponent.decorators = [
    { type: Component, args: [{
                selector: 'esri-layers-toggle, esri-layersToggle',
                template: `<div esriCustomWidget [position]="position">
  <!-- Only display if there is a map and it has layers -->
  <div *ngIf="map?.layers.length > 0" class="esri-layers-toggle">
    <div *ngFor="let layer of map.layers.toArray()">
      <input type="checkbox" [checked]="layer.visible" (click)="onCheck($event, layer)" /> {{layer.title}}
      <a href="javascript:void(0)" (click)="onZoomLayer(layer)">Zoom</a>
      <esri-sublayers-toggle [layer]="layer" *ngIf="layer.sublayers && layer.sublayers.items"></esri-sublayers-toggle>
    </div>
  </div>
</div>`,
                styles: [`.esri-layers-toggle{z-index:99;background-color:#fff;border-radius:8px;padding:10px;opacity:.75}`]
            },] },
];
/** @nocollapse */
LayersToggleComponent.ctorParameters = () => [
    { type: EsriMapService, },
];
LayersToggleComponent.propDecorators = {
    "position": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class SubLayersToggleComponent {
    constructor() { }
    /**
     * @param {?} layer
     * @return {?}
     */
    set layer(layer) {
        this._sublayers = layer.sublayers
            .toArray()
            .slice()
            .reverse();
    }
    /**
     * @param {?} $event
     * @param {?} sublayer
     * @return {?}
     */
    onCheck($event, sublayer) {
        sublayer.visible = $event.target.checked;
    }
}
SubLayersToggleComponent.decorators = [
    { type: Component, args: [{
                selector: 'esri-sublayers-toggle, esri-sublayersToggle',
                template: `<div *ngFor="let sublayer of _sublayers" class="sublayers">
  <input type="checkbox" [checked]="sublayer.visible" (click)="onCheck($event, sublayer)" /> {{sublayer.title}}
  <esri-sublayers-toggle [layer]="sublayer" *ngIf="sublayer.sublayers && sublayer.sublayers.toArray()"></esri-sublayers-toggle><!--recursive sub layers-->
</div>
`,
                styles: [`.sublayers{padding-left:15px}`]
            },] },
];
/** @nocollapse */
SubLayersToggleComponent.ctorParameters = () => [];
SubLayersToggleComponent.propDecorators = {
    "layer": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class AngularEsriModule {
}
AngularEsriModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    MapComponent,
                    CustomWidgetDirective,
                    LayersToggleComponent,
                    SubLayersToggleComponent
                ],
                exports: [
                    MapComponent,
                    CustomWidgetDirective,
                    LayersToggleComponent
                ],
                providers: [EsriModuleProvider, EsriMapService]
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

export { AngularEsriModule, EsriModuleProvider, environment as ɵb, EsriMapService as ɵc, MapComponent as ɵa, CustomWidgetDirective as ɵd, LayersToggleComponent as ɵe, SubLayersToggleComponent as ɵf };
//# sourceMappingURL=angular-esri-components.js.map
