import { Injectable, EventEmitter, Component, Input, Output, ViewChild, Directive, ElementRef, NgModule } from '@angular/core';
import { loadModules } from 'esri-loader';
import { __read } from 'tslib';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var /** @type {?} */ environment = {
    production: true,
    arcGisScriptUrl: 'https://js.arcgis.com/4.7/',
    arcGisCssUrl: 'http://js.arcgis.com/4.7/esri/css/main.css'
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var EsriModuleProvider = /** @class */ (function () {
    function EsriModuleProvider() {
    }
    /**
     * @param {?} moduleNames
     * @return {?}
     */
    EsriModuleProvider.prototype.require = function (moduleNames) {
        return loadModules(moduleNames, {
            // the specific version of the API that is to be used
            url: environment.arcGisScriptUrl
        });
    };
    return EsriModuleProvider;
}());
EsriModuleProvider.decorators = [
    { type: Injectable },
];
/** @nocollapse */
EsriModuleProvider.ctorParameters = function () { return []; };

var EsriMapService = /** @class */ (function () {
    /**
     * @param {?} moduleProvider
     */
    function EsriMapService(moduleProvider) {
        this.moduleProvider = moduleProvider;
        this.isLoaded = new EventEmitter();
    }
    /**
     * @param {?} mapViewProperties
     * @param {?} mapEl
     * @param {?} map
     * @return {?}
     */
    EsriMapService.prototype.prepareViewProps = function (mapViewProperties, mapEl, map) {
        var /** @type {?} */ newViewProps = this.extend({}, mapViewProperties);
        if (!newViewProps.container) {
            newViewProps.container = mapEl.nativeElement.id;
        }
        if (!newViewProps.map) {
            newViewProps.map = map;
        }
        return newViewProps;
    };
    /**
     * @param {?} mapProperties
     * @param {?} viewProperties
     * @param {?} mapEl
     * @param {?=} viewType
     * @return {?}
     */
    EsriMapService.prototype.loadMap = function (mapProperties, viewProperties, mapEl, viewType) {
        var _this = this;
        if (viewType === void 0) { viewType = 'MapView'; }
        return this.moduleProvider
            .require(['esri/Map', 'esri/views/' + viewType])
            .then(function (_a) {
            var _b = __read(_a, 2), Map = _b[0], View = _b[1];
            // create map
            var /** @type {?} */ map = new Map(mapProperties);
            // prepare properties that should be set locally
            // create a new object so as to not modify the provided object
            var /** @type {?} */ newViewProps = _this.prepareViewProps(viewProperties, mapEl, map);
            // create the MapView
            var /** @type {?} */ view = new View(newViewProps);
            _this.map = map;
            _this.view = view;
            _this.isLoaded.emit();
            return {
                map: map,
                view: view
            };
        });
    };
    /**
     * @param {?} webMapProperties
     * @param {?} viewProperties
     * @param {?} mapEl
     * @param {?=} viewType
     * @return {?}
     */
    EsriMapService.prototype.loadWebMap = function (webMapProperties, viewProperties, mapEl, viewType) {
        var _this = this;
        if (viewType === void 0) { viewType = 'MapView'; }
        return this.moduleProvider
            .require(['esri/WebMap', 'esri/views/' + viewType])
            .then(function (_a) {
            var _b = __read(_a, 2), WebMap = _b[0], View = _b[1];
            // create map
            var /** @type {?} */ map = new WebMap(webMapProperties);
            // prepare properties that should be set locally
            // create a new object so as to not modify the provided object
            var /** @type {?} */ newViewProps = _this.prepareViewProps(viewProperties, mapEl, map);
            // create the MapView
            var /** @type {?} */ view = new View(newViewProps);
            _this.map = map;
            _this.view = view;
            _this.isLoaded.emit();
            return {
                map: map,
                view: view
            };
        });
    };
    /**
     * @param {?} element
     * @param {?} position
     * @return {?}
     */
    EsriMapService.prototype.addWidget = function (element, position) {
        this.view.ui.add(element, position);
    };
    /**
     * @param {?} obj
     * @param {?} src
     * @return {?}
     */
    EsriMapService.prototype.extend = function (obj, src) {
        Object.keys(src).forEach(function (key) {
            obj[key] = src[key];
        });
        return obj;
    };
    return EsriMapService;
}());
EsriMapService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
EsriMapService.ctorParameters = function () { return [
    { type: EsriModuleProvider, },
]; };

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var MapComponent = /** @class */ (function () {
    /**
     * @param {?} mapService
     */
    function MapComponent(mapService) {
        this.mapService = mapService;
        this.mapViewProperties = {};
        this.viewType = 'MapView';
        this.mapInit = new EventEmitter();
    }
    /**
     * @return {?}
     */
    MapComponent.prototype.ngOnInit = function () {
        if (this.map) {
            // map is already initialized
            return;
        }
        this.loadMap();
    };
    /**
     * @return {?}
     */
    MapComponent.prototype.loadMap = function () {
        var _this = this;
        var /** @type {?} */ mapPromise;
        // determine if loading a WebMap or creating a custom map
        if (this.mapProperties) {
            mapPromise = this.mapService.loadMap(this.mapProperties, this.mapViewProperties, this.mapEl, this.viewType);
        }
        else if (this.webMapProperties) {
            mapPromise = this.mapService.loadWebMap(this.webMapProperties, this.mapViewProperties, this.mapEl, this.viewType);
        }
        else {
            console.error('Proper map properties were not provided');
            return;
        }
        mapPromise.then(function (mapInfo) {
            _this.map = mapInfo.map;
            _this.mapView = mapInfo.view;
            // emit event informing application that the map has been loaded
            _this.mapInit.emit({
                map: _this.map,
                mapView: _this.mapView
            });
            _this.mapInit.complete();
        });
    };
    return MapComponent;
}());
MapComponent.decorators = [
    { type: Component, args: [{
                selector: 'esri-map',
                template: "<div class=\"map\" id=\"esri-map\" #map></div>",
                styles: ["\n    /* Required CSS for the ArcGIS API for JavaScript */\n    @import '" + environment.arcGisCssUrl + "';\n    .map {\n      height: 100%;\n      width: 100%;\n      margin: 0;\n      padding: 0;\n    }\n  "]
            },] },
];
/** @nocollapse */
MapComponent.ctorParameters = function () { return [
    { type: EsriMapService, },
]; };
MapComponent.propDecorators = {
    "mapEl": [{ type: ViewChild, args: ['map',] },],
    "mapProperties": [{ type: Input },],
    "webMapProperties": [{ type: Input },],
    "mapViewProperties": [{ type: Input },],
    "viewType": [{ type: Input },],
    "mapInit": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var CustomWidgetDirective = /** @class */ (function () {
    /**
     * @param {?} el
     * @param {?} mapService
     */
    function CustomWidgetDirective(el, mapService) {
        this.el = el;
        this.mapService = mapService;
    }
    /**
     * @return {?}
     */
    CustomWidgetDirective.prototype.ngOnInit = function () {
        var _this = this;
        this.mapService.isLoaded.subscribe(function () {
            // after map is loaded then add widget
            _this.mapService.addWidget(_this.el.nativeElement, _this.position);
        });
    };
    return CustomWidgetDirective;
}());
CustomWidgetDirective.decorators = [
    { type: Directive, args: [{
                selector: '[esriCustomWidget], [esri-customWidget]'
            },] },
];
/** @nocollapse */
CustomWidgetDirective.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: EsriMapService, },
]; };
CustomWidgetDirective.propDecorators = {
    "position": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var LayersToggleComponent = /** @class */ (function () {
    /**
     * @param {?} mapService
     */
    function LayersToggleComponent(mapService) {
        this.mapService = mapService;
    }
    /**
     * @return {?}
     */
    LayersToggleComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.mapService.isLoaded.subscribe(function () {
            _this.map = _this.mapService.map;
            _this.view = _this.mapService.view;
        });
    };
    /**
     * @param {?} $event
     * @param {?} layer
     * @return {?}
     */
    LayersToggleComponent.prototype.onCheck = function ($event, layer) {
        layer.visible = $event.target.checked;
    };
    /**
     * @param {?} layer
     * @return {?}
     */
    LayersToggleComponent.prototype.onZoomLayer = function (layer) {
        if (this.view.type === '2d') {
            ((this.view)).goTo(layer.fullExtent);
        }
        else {
            var /** @type {?} */ sceneView = (this.view);
            sceneView.goTo({
                target: layer.fullExtent,
                heading: sceneView.camera.heading
            });
        }
    };
    return LayersToggleComponent;
}());
LayersToggleComponent.decorators = [
    { type: Component, args: [{
                selector: 'esri-layers-toggle, esri-layersToggle',
                template: "<div esriCustomWidget [position]=\"position\">\n  <!-- Only display if there is a map and it has layers -->\n  <div *ngIf=\"map?.layers.length > 0\" class=\"esri-layers-toggle\">\n    <div *ngFor=\"let layer of map.layers.toArray()\">\n      <input type=\"checkbox\" [checked]=\"layer.visible\" (click)=\"onCheck($event, layer)\" /> {{layer.title}}\n      <a href=\"javascript:void(0)\" (click)=\"onZoomLayer(layer)\">Zoom</a>\n      <esri-sublayers-toggle [layer]=\"layer\" *ngIf=\"layer.sublayers && layer.sublayers.items\"></esri-sublayers-toggle>\n    </div>\n  </div>\n</div>",
                styles: [".esri-layers-toggle{z-index:99;background-color:#fff;border-radius:8px;padding:10px;opacity:.75}"]
            },] },
];
/** @nocollapse */
LayersToggleComponent.ctorParameters = function () { return [
    { type: EsriMapService, },
]; };
LayersToggleComponent.propDecorators = {
    "position": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var SubLayersToggleComponent = /** @class */ (function () {
    function SubLayersToggleComponent() {
    }
    Object.defineProperty(SubLayersToggleComponent.prototype, "layer", {
        /**
         * @param {?} layer
         * @return {?}
         */
        set: function (layer) {
            this._sublayers = layer.sublayers
                .toArray()
                .slice()
                .reverse();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @param {?} $event
     * @param {?} sublayer
     * @return {?}
     */
    SubLayersToggleComponent.prototype.onCheck = function ($event, sublayer) {
        sublayer.visible = $event.target.checked;
    };
    return SubLayersToggleComponent;
}());
SubLayersToggleComponent.decorators = [
    { type: Component, args: [{
                selector: 'esri-sublayers-toggle, esri-sublayersToggle',
                template: "<div *ngFor=\"let sublayer of _sublayers\" class=\"sublayers\">\n  <input type=\"checkbox\" [checked]=\"sublayer.visible\" (click)=\"onCheck($event, sublayer)\" /> {{sublayer.title}}\n  <esri-sublayers-toggle [layer]=\"sublayer\" *ngIf=\"sublayer.sublayers && sublayer.sublayers.toArray()\"></esri-sublayers-toggle><!--recursive sub layers-->\n</div>\n",
                styles: [".sublayers{padding-left:15px}"]
            },] },
];
/** @nocollapse */
SubLayersToggleComponent.ctorParameters = function () { return []; };
SubLayersToggleComponent.propDecorators = {
    "layer": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var AngularEsriModule = /** @class */ (function () {
    function AngularEsriModule() {
    }
    return AngularEsriModule;
}());
AngularEsriModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [
                    MapComponent,
                    CustomWidgetDirective,
                    LayersToggleComponent,
                    SubLayersToggleComponent
                ],
                exports: [
                    MapComponent,
                    CustomWidgetDirective,
                    LayersToggleComponent
                ],
                providers: [EsriModuleProvider, EsriMapService]
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

export { AngularEsriModule, EsriModuleProvider, environment as ɵb, EsriMapService as ɵc, MapComponent as ɵa, CustomWidgetDirective as ɵd, LayersToggleComponent as ɵe, SubLayersToggleComponent as ɵf };
//# sourceMappingURL=angular-esri-components.js.map
